# reimage

A simple utility that helps you organize your photos by the date they were shot on.

### Install
#### Using pip
`python3 -m pip install reimage`

#### From source
To install from source run `python3 -m pip install .` from within the root directory